////////////////////////////////////////////////////////

var video_mode = 7; // 800x600
var video_depth = 16; // 16 bit mode

var player_speed; // moves the player
var temp_angle; // temporary angle used for the ring of fire
var number_of_flames = 0; // keeps track of the number of flames in order to get good frame rates

//////////////////////////////////////////////////////////////

sound beep_sound = <beep.wav>;

//////////////////////////////////////////////////////////////

bmap cursor_pcx = <cursor.pcx>;

bmap main_pcx = <main.pcx>;
bmap shield_pcx = <shield.pcx>;
bmap mace_pcx = <mace.pcx>;
bmap armor_pcx = <armor.pcx>;
bmap ring_pcx = <ring.pcx>;
bmap blue_pcx = <blue.pcx>;
bmap red_pcx = <red.pcx>;
bmap green_pcx = <green.pcx>;

//////////////////////////////////////////////////////////////

function check_inventory();
function use_shield();
function use_mace();
function use_armor();
function use_ring();
function attach_item();
function fire_action();

//////////////////////////////////////////////////////////////

define items skill30;
define armour skill41; // armor, but I can't use the same name twice
define attack skill42;
define strength skill43;

define shield 1;
define mace 2;
define armor 4; 
define ring 8;

//////////////////////////////////////////////////////////////

string inventory_wmb = <inventory.wmb>;

string shield_mdl = <shield.mdl>;
string mace_mdl = <mace.mdl>;
string armor_mdl = <armor.mdl>;
string fire_pcx = <fire.pcx>;

include <newdebug.wdl>;

//////////////////////////////////////////////////////////////

panel main_pan // the main panel for the items in the inventory
{
	bmap = main_pcx;
	pos_x = 700;
	pos_y = 0;
	layer = 10;
	hbar = 7, 488, 85, blue_pcx, 1, player.armour;
	hbar = 7, 518, 85, red_pcx, 1, player.attack;
	hbar = 7, 550, 85, green_pcx, 1, player.strength;
	flags = refresh, d3d, visible;
}

panel shield_pan // displays the shield on the panel
{
	bmap = shield_pcx;
	pos_x = 715;
	pos_y = 30;
	layer = 11;
	flags = overlay, refresh, d3d;
	on_click use_shield;
}

panel mace_pan // displays the mace on the panel
{
	bmap = mace_pcx;
	pos_x = 730;
	pos_y = 145;
	layer = 11;
	flags = overlay, refresh, d3d;
	on_click use_mace;
}

panel armor_pan // displays the armor on the panel
{
	bmap = armor_pcx;
	pos_x = 710;
	pos_y = 255;
	layer = 11;
	flags = overlay, refresh, d3d;
	on_click use_armor;
}

panel ring_pan // displays the ring on the panel
{
	bmap = ring_pcx;
	pos_x = 710;
	pos_y = 365;
	layer = 11;
	flags = overlay, refresh, d3d;
	on_click use_ring;
}

////////////////////////////////////////////////////////////////

function main()
{
	level_load (inventory_wmb);
	wait (2); // wait for the level to be loaded
	clip_size = 0; // show all the triangles for all the models
	on_d = null; // disable the debug panel (key "D") because it is used for movement
	fps_max = 40; // lock the frame rate to 40 fps
	check_inventory();
	toggle_debug();
}	

action player_moves // attached to the player
{
	player = me; // I'm the player
	player.items = 0;
	player.armour = 20;
	player.attack = 30;
	player.strength = 35;
	while (1) 
	{
		camera.x = player.x - 200 * cos(player.pan); // 200 = distance between the player and the camera
		camera.y = player.y - 200 * sin(player.pan); // same value here
		camera.z = player.z + 200; // above the player
		camera.pan = player.pan; // the camera looks in the same direction with the player
		camera.tilt = -30; // look down at the player
		my.pan += 4 * (key_a - key_d) * time - 20 * mouse_force.x * time; // rotates with the keys A and D or with the mouse
		player_speed.x = 10 * (key_w - key_s) * time; // moves forward / backward with W / S
		player_speed.y = 0;
		player_speed.z = 0;
		if ((key_w + key_s) != 0) // if the player is walking
		{
			ent_cycle("walk", my.skill20); // play walk frames animation
			my.skill20 += 4 * (key_w - key_s) * time; // animation forward / backward
			my.skill20 %= 100; 
		}
		else 
		{
			if (mouse_left != 1) // the player is standing
			{
				ent_cycle("stand", my.skill20); // play stand frames animation
				my.skill20 += 2 * time; // "stand" animation speed
				my.skill20 %= 100; 
			}
			else // the player has pressed the left mouse button
			{
				if (ring_pan.visible != on && mouse_mode == 0 && number_of_flames == 0) // the ring has been used
				{
					my.skill20 = 0;
					ent_cycle("attack", my.skill20); // play stand frames animation
					if (my.skill20 < 99)
					{
						my.skill20 += 0.5 * time; // "attack" animation played once (no loop)
					}
				}
				while (mouse_left == 1) {wait (1);}
			}			
		}				
		move_mode = ignore_passable;
		ent_move(player_speed, nullvector);
		wait (1);
	}
}

action shield_init
{
	my.passable = on;
	while (player == null) {wait (1);}
	while (vec_dist (my.x, player.x) > 50)
	{
		ent_cycle("idle", my.skill20); // play stand frames animation
		my.skill20 += 3 * time; // "idle" animation speed
		my.skill20 %= 100; 		
		wait (1);
	}
	player.items += shield;
	ent_remove (me);		
}

action mace_init
{
	my.passable = on;
	while (player == null) {wait (1);}
	while (vec_dist (my.x, player.x) > 50)
	{
		ent_cycle("idle", my.skill20); // play stand frames animation
		my.skill20 += 3 * time; // "idle" animation speed
		my.skill20 %= 100; 		
		wait (1);
	}
	player.items += mace;
	ent_remove (me);
}	

action armor_init
{
	my.passable = on;
	while (player == null) {wait (1);}
	while (vec_dist (my.x, player.x) > 50)
	{
		ent_cycle("stand", my.skill20); // play stand frames animation
		my.skill20 += 2 * time; // "stand" animation speed
		my.skill20 %= 100; 		
		wait (1);
	}
	player.items += armor;
	ent_remove (me);
}	

action ring_init
{
	my.passable = on;
	while (player == null) {wait (1);}
	while (vec_dist (my.x, player.x) > 50)
	{
		ent_cycle("frame", my.skill20); // play "frame" animation
		my.skill20 += 2 * time; // "frame" animation speed
		my.skill20 %= 100; 		
		wait (1);
	}
	player.items += ring;
	ent_remove (me);
}	

function check_inventory()
{
	while (1)
	{
		if (player.items > 0)
		{
			if (player.items == 1) // 1 + 0 + 0 + 0
			{
				shield_pan.visible = on;
				mace_pan.visible = off;
				armor_pan.visible = off;
				ring_pan.visible = off;
			}
			if (player.items == 2) // 0 + 2 + 0 + 0
			{
				shield_pan.visible = off;
				mace_pan.visible = on;
				armor_pan.visible = off;
				ring_pan.visible = off;
			}
			if (player.items == 3) // 1 + 2 + 0 + 0
			{
				shield_pan.visible = on;
				mace_pan.visible = on;
				armor_pan.visible = off;
				ring_pan.visible = off;
			}
			if (player.items == 4) // 0 + 0 + 4 + 0
			{
				shield_pan.visible = off;
				mace_pan.visible = off;
				armor_pan.visible = on;
				ring_pan.visible = off;
			}
			if (player.items == 5) // 1 + 0 + 4 + 0
			{
				shield_pan.visible = on;
				mace_pan.visible = off;
				armor_pan.visible = on;
				ring_pan.visible = off;
			}
			if (player.items == 6) // 0 + 2 + 4 + 0
			{
				shield_pan.visible = off;
				mace_pan.visible = on;
				armor_pan.visible = on;
				ring_pan.visible = off;
			}
			if (player.items == 7) // 1 + 2 + 4 + 0
			{
				shield_pan.visible = on;
				mace_pan.visible = on;
				armor_pan.visible = on;
				ring_pan.visible = off;
			}
			if (player.items == 8) // 0 + 0 + 0 + 8
			{
				shield_pan.visible = off;
				mace_pan.visible = off;
				armor_pan.visible = off;
				ring_pan.visible = on;
			}
			if (player.items == 9) // 1 + 0 + 0 + 8
			{
				shield_pan.visible = on;
				mace_pan.visible = off;
				armor_pan.visible = off;
				ring_pan.visible = on;
			}
			if (player.items == 10) // 0 + 2 + 0 + 8
			{
				shield_pan.visible = off;
				mace_pan.visible = on;
				armor_pan.visible = off;
				ring_pan.visible = on;
			}
			if (player.items == 11) // 1 + 2 + 0 + 8
			{
				shield_pan.visible = on;
				mace_pan.visible = on;
				armor_pan.visible = off;
				ring_pan.visible = on;
			}
			if (player.items == 12) // 0 + 0 + 4 + 8
			{
				shield_pan.visible = off;
				mace_pan.visible = off;
				armor_pan.visible = on;
				ring_pan.visible = on;
			}
			if (player.items == 13) // 1 + 0 + 4 + 8
			{
				shield_pan.visible = on;
				mace_pan.visible = off;
				armor_pan.visible = on;
				ring_pan.visible = on;
			}
			if (player.items == 14) // 0 + 2 + 4 + 8
			{
				shield_pan.visible = off;
				mace_pan.visible = on;
				armor_pan.visible = on;
				ring_pan.visible = on;
			}
			if (player.items == 15) // 1 + 2 + 4 + 8
			{
				shield_pan.visible = on;
				mace_pan.visible = on;
				armor_pan.visible = on;
				ring_pan.visible = on;
			}
				
		}
		else
		{
			shield_pan.visible = off;
			mace_pan.visible = off;
			armor_pan.visible = off;
			ring_pan.visible = off;
		}

		mouse_map = cursor_pcx;
		mouse_pos.x = pointer.x;
		mouse_pos.y = pointer.y;
		if (mouse_right == 1)
		{
			mouse_mode = (mouse_mode + 2) % 4;
			while (mouse_right == 1) {wait (1);}
		}		

		wait (1);
	}
}

function use_shield()
{
	player.items -= shield; // remove the shield from the panel
	ent_create(shield_mdl, player.pos, attach_item);
	player.strength += 30; // bigger hbar
}

function use_mace()
{
	player.items -= mace; // remove the mace from the panel
	ent_create(mace_mdl, player.pos, attach_item);
	player.attack += 50; // bigger hbar
}

function use_armor()
{
	player.items -= armor; // remove the armor from the panel
	ent_create(armor_mdl, player.pos, attach_item);
	player.armour += 40; // bigger hbar
}

function attach_item()
{
	proc_late();
	my.passable = on;
	my.metal = on;
	my.albedo = 0;
	while(player != null)
	{
		vec_set(my.x, player.x);
	   	vec_set(my.pan, player.pan);
   		my.frame = player.frame;
	   	my.next_frame = player.next_frame;
   		wait(1);
	}
}

function use_ring()
{
	player.items -= ring;
	while (1)
	{
		if (mouse_left == 1 && mouse_mode == 0 && number_of_flames == 0) // the mouse pointer is invisible and not too many entities are visible
		{
			temp_angle = 0;
			while (temp_angle < 360)
			{
				temp_angle += 3;
				temp.x = player.x + 100 * cos(temp_angle);
				temp.y = player.y + 100 * sin(temp_angle);
				temp.z = player.z;
				ent_create (fire_pcx, temp, fire_action);
			}
		}
		while (mouse_left == 1) {wait (1);}
  		wait(1);
	}
}

function fire_action()
{
	number_of_flames += 1; // add another flame entity to this var
	my.passable = on;
	my.flare = on;
	my.bright = on;
	my.oriented = on;
	my.pan = random(360);
	while (my.pan < 1500)
	{
		my.pan += (5 + random(3)) * time;
		my.z -= 0.4 * time;
		wait (1);
	}
	number_of_flames -= 1;
	ent_remove (me);
}

